@@ -4,7 +4,7 @@
 
     Experimental docutils writers for HTML5 handling Sphinx' custom nodes.
 
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -12,8 +12,7 @@ import os
 import posixpath
 import re
 import warnings
-from typing import Any, Iterable, Tuple
-from typing import cast
+from typing import Any, Iterable, Tuple, cast
 
 from docutils import nodes
 from docutils.nodes import Element, Node, Text
@@ -22,7 +21,7 @@ from docutils.writers.html5_polyglot import HTMLTranslator as BaseTranslator
 from sphinx import addnodes
 from sphinx.builders import Builder
 from sphinx.deprecation import RemovedInSphinx40Warning
-from sphinx.locale import admonitionlabels, _, __
+from sphinx.locale import _, __, admonitionlabels
 from sphinx.util import logging
 from sphinx.util.docutils import SphinxTranslator
 from sphinx.util.images import get_image_size
@@ -397,9 +396,12 @@ class HTML5Translator(SphinxTranslator, BaseTranslator):
         else:
             opts = {}
 
+        if linenos and self.builder.config.html_codeblock_linenos_style:
+            linenos = self.builder.config.html_codeblock_linenos_style
+
         highlighted = self.highlighter.highlight_block(
             node.rawsource, lang, opts=opts, linenos=linenos,
-            location=(self.builder.current_docname, node.line), **highlight_args
+            location=node, **highlight_args
         )
         starttag = self.starttag(node, 'div', suffix='',
                                  CLASS='highlight-%s notranslate' % lang)
